# We have data for these file numbers
file_numbers = {
#     '031': {}, # Handelsproducten
#     '051': {}, # Voorschrijfpr. geneesmiddel identific.
#     '601': {}, # Aanv.voorwaarden Med.Bew. en tekstblok
#     '655': {}, # Bewakingen: te controleren indicaties
#     '656': {}, # Bewakingen: Kenmerken
#     '681': {}, # MFB: Trigger geneesmiddelkeuze
#     '682': {}, # MFB: Vervanging medicatiebewaking
#     '684': {}, # MFB: Koppeling externe coderingen
    '685': {}, # MFB: Parameters
    '686': {}, # MFB: Attributen
    '689': {}, # MFB: Functie
    '690': {}, # MFB: Protocol
    '691': {}, # MFB: Protocol flow
    '692': {}, # MFB: Vragen
    '693': {}, # MFB: Actie
    '694': {}, # MFB: Actie - Parameter
    '695': {}, # MFB: Vraag - Functie - Parameter
    '696': {}, # MFB: Vraag - Functie - Waardelijst
    '697': {}, # MFB: Vraag - Functie - Attribuut
    '699': {}, # MFB: Waardelijsten meerdere niveaus
#     '711': {}, # Generieke producten
    '902': {}, # Thesauri totaal
#     '911': {}, # Header relatie bestand
#     '912': {}, # Relatie bestand
    '921': {}, # Tekstblokken ASCII
#     '922': {}, # Tekstblokken HTML
}
