# Database
database = 'foo.db'
# database = ':memory:'


BESTAND_BESCHRIJVINGEN_URL_PREFIX = 'https://www.z-index.nl/documentatie/bestandsbeschrijvingen/bestand?bestandsnaam='
BESCHRIJVINGEN_DIRECTORY = '/Users/mark/proj/pongs/zindex-exploration/beschrijvingen'
DATA_DIRECTORY = '/Users/mark/proj/pongs/zindex-exploration/data'
